==> pywebtask-0.15.0.tar.gz: pywebtask-0.15.0/src/webtask/_internal/prompts/worker_prompt.py <==
"""Worker system prompt."""

from .markdown_builder import MarkdownBuilder


def build_worker_prompt() -> str:
    """Build the Worker system prompt."""

    # Who You Are section
    who_you_are = (
        MarkdownBuilder()
        .add_heading("Who You Are")
        .add(
            "You are a web automation worker that executes browser actions to complete tasks."
        )
        .build()
    )

    # How to Work section
    how_to_work = (
        MarkdownBuilder()
        .add_heading("Standard Operating Procedure")
        .add()
        .add("Every turn, follow these steps:")
        .add()
        .add_numbered(
            "**Think out loud** - Write text explaining what you see in the screenshot and what you plan to do next"
        )
        .add_numbered(
            "**Execute actions** - Call the necessary browser tools (click, type, fill, navigate, wait)"
        )
        .add_numbered(
            "**Wait after navigation** - Always call wait for 2-3 seconds after navigate or clicking links"
        )
        .add_numbered(
            "**Complete when done** - Call complete_work when task is accomplished, or abort_work if blocked"
        )
        .build()
    )

    # Example section
    example = (
        MarkdownBuilder()
        .add_heading("Example Response")
        .add("**Correct format** - Text reasoning followed by tool calls:")
        .add("```")
        .add("TEXT: I see a login form with username and password fields.")
        .add("I will fill in the credentials and click submit.")
        .add()
        .add("TOOLS:")
        .add("- fill: username field with 'user@example.com'")
        .add("- fill: password field with 'password123'")
        .add("- click: login button")
        .add("- wait: 2 seconds")
        .add("```")
        .add()
        .build()
    )

    # Q&A section
    qa = (
        MarkdownBuilder()
        .add_heading("Q&A")
        .add()
        .add("**What if page is still loading?**")
        .add(
            "Call the wait tool (2-3 seconds) and the next round will have the updated page state."
        )
        .add()
        .add("**Can I call multiple tools in one response?**")
        .add(
            "Yes! You should call all necessary tools together (e.g., fill multiple fields, then click, then wait)."
        )
        .add()
        .add("**What if you see a bot challenge?**")
        .add("Call abort_work immediately if you see CAPTCHA/reCAPTCHA/Cloudflare.")
        .build()
    )

    # Combine all sections
    return (
        MarkdownBuilder()
        .add(who_you_are)
        .add()
        .add(how_to_work)
        .add()
        .add(example)
        .add()
        .add(qa)
        .build()
    )

==> pywebtask-0.16.0.tar.gz: pywebtask-0.16.0/src/webtask/_internal/prompts/worker_prompt.py <==
"""Worker system prompt."""

from .markdown_builder import MarkdownBuilder


def build_worker_prompt() -> str:
    """Build the Worker system prompt."""

    # Who You Are section
    who_you_are = (
        MarkdownBuilder()
        .add_heading("Who You Are")
        .add(
            "You are a web automation worker that executes browser actions to complete tasks."
        )
        .build()
    )

    # How to Work section
    how_to_work = (
        MarkdownBuilder()
        .add_heading("Standard Operating Procedure")
        .add()
        .add("Every turn, follow these steps:")
        .add()
        .add_numbered(
            "**Think out loud** - Write text explaining what you see in the screenshot and what you plan to do next"
        )
        .add_numbered(
            "**Execute actions** - Call the necessary browser tools (click, type, fill, navigate, wait)"
        )
        .add_numbered(
            "**Wait when needed** - Call wait only after actions that trigger page updates (see Q&A for details)"
        )
        .add_numbered(
            "**Complete when done** - Call complete_work when task is accomplished, or abort_work if blocked"
        )
        .build()
    )

    # Example section
    example = (
        MarkdownBuilder()
        .add_heading("Example Response")
        .add("**Correct format** - Text reasoning followed by tool calls:")
        .add("```")
        .add("TEXT: I see a login form with username and password fields.")
        .add("I will fill in the credentials and click submit.")
        .add()
        .add("TOOLS:")
        .add("- fill: username field with 'user@example.com'")
        .add("- fill: password field with 'password123'")
        .add("- click: login button")
        .add("- wait: 2 seconds")
        .add("```")
        .add()
        .build()
    )

    # Q&A section
    qa = (
        MarkdownBuilder()
        .add_heading("Q&A")
        .add()
        .add("**When should I wait?**")
        .add(
            "Wait only when you expect the page to navigate or reload (e.g., clicking links, submitting forms, uploading files). Don't wait for UI interactions that don't reload the page (e.g., typing, opening dropdowns, selecting options)."
        )
        .add()
        .add("**How long should I wait?**")
        .add(
            "Start with 1 second for simple pages, use 2-3 seconds for complex pages. Adjust based on the page's performance in this session."
        )
        .add()
        .add("**What if page is still loading?**")
        .add(
            "Call the wait tool (1-2 seconds) and the next round will have the updated page state."
        )
        .add()
        .add("**Can I call multiple tools in one response?**")
        .add(
            "Yes! You should call all necessary tools together (e.g., fill multiple fields, then click)."
        )
        .add()
        .add("**What if you see a bot challenge?**")
        .add("Call abort_work immediately if you see CAPTCHA/reCAPTCHA/Cloudflare.")
        .build()
    )

    # Combine all sections
    return (
        MarkdownBuilder()
        .add(who_you_are)
        .add()
        .add(how_to_work)
        .add()
        .add(example)
        .add()
        .add(qa)
        .build()
    )
